==> jonas-JONAS_4_6_4.tar.gz: jonas-JONAS_4_6_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/ApplyUserAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;

import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JonasObjectName;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.WhereAreYou;
import org.objectweb.jonas.webapp.jonasadmin.deploy.BaseDeployAction;


/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyUserAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Form used
        JoramUserForm oForm = (JoramUserForm) p_Form;
        String idString = (String) m_Session.getAttribute("currentId");
        String localIdString = (String) m_Session.getAttribute("localId");
        boolean isLocalServer;
        if (localIdString.equals(idString)) {
            isLocalServer = true;
        } else {
            isLocalServer = false;
        }

        try {
            ObjectName oObjectName;
            ObjectName joramAdapterON = (ObjectName) JonasManagementRepr.queryNames(JoramObjectName.joramAdapter()).iterator().next();
            if (JonasManagementRepr.isRegistered(joramAdapterON)) {
                oObjectName = joramAdapterON;
            } else {
                oObjectName = JoramObjectName.joramAdmin();
            }
            if (isLocalServer) {
                Object[] asParam = {
                    oForm.getName(), oForm.getPassword()
                };
                String[] asSignature = {
                    "java.lang.String", "java.lang.String"
                };
                JonasManagementRepr.invoke(oObjectName, "createUser", asParam, asSignature);
            } else {
                Integer idInteger = (new Integer(idString));
                Object[] asParam = {
                        oForm.getName(), oForm.getPassword(), idInteger
                    };
                String[] asSignature = {
                        "java.lang.String", "java.lang.String", "int"
                    };
                JonasManagementRepr.invoke(oObjectName, "createUser", asParam, asSignature);
            }
            oForm.reset(p_Mapping, p_Request);
        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Joram User"));
    }
}

==> jonas-JONAS_4_10_4.tar.gz: jonas-JONAS_4_10_4/jonas/src/org/objectweb/jonas/webapp/jonasadmin/joramplatform/ApplyUserAction.java <==
/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.webapp.jonasadmin.joramplatform;

import java.io.IOException;
import java.util.Set;

import javax.management.InstanceNotFoundException;
import javax.management.ObjectName;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.objectweb.jonas.jmx.JonasManagementRepr;
import org.objectweb.jonas.jmx.JoramObjectName;
import org.objectweb.jonas.webapp.jonasadmin.deploy.BaseDeployAction;


/**
 * @author Adriana Danes
 * Creation of new destinations
 */

public class ApplyUserAction extends BaseDeployAction {

// --------------------------------------------------------- Public Methods

    public ActionForward executeAction(ActionMapping p_Mapping, ActionForm p_Form
        , HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        // Current JOnAS server
        String jonasServerName =  m_WhereAreYou.getCurrentJonasServerName();

        // Form used
        JoramUserForm oForm = (JoramUserForm) p_Form;
        String idString = (String) m_Session.getAttribute("currentId");
        String localIdString = (String) m_Session.getAttribute("localId");
        boolean isLocalServer;
        if (localIdString.equals(idString)) {
            isLocalServer = true;
        } else {
            isLocalServer = false;
        }

        try {
            ObjectName oObjectName = null;
            Set adapterOns = JonasManagementRepr.queryNames(JoramObjectName.joramAdapter(), jonasServerName);
            if (adapterOns.isEmpty()) {
                throw new InstanceNotFoundException();
            }
            ObjectName joramAdapterON = (ObjectName) adapterOns.iterator().next();
            if (JonasManagementRepr.isRegistered(joramAdapterON, jonasServerName)) {
                oObjectName = joramAdapterON;
            } else {
                //oObjectName = JoramObjectName.joramAdmin();
            }
            if (isLocalServer) {
                Object[] asParam = {
                    oForm.getName(), oForm.getPassword()
                };
                String[] asSignature = {
                    "java.lang.String", "java.lang.String"
                };
                JonasManagementRepr.invoke(oObjectName, "createUser", asParam, asSignature, jonasServerName);
            } else {
                Integer idInteger = (new Integer(idString));
                Object[] asParam = {
                        oForm.getName(), oForm.getPassword(), idInteger
                    };
                String[] asSignature = {
                        "java.lang.String", "java.lang.String", "int"
                    };
                JonasManagementRepr.invoke(oObjectName, "createUser", asParam, asSignature, jonasServerName);
            }
            oForm.reset(p_Mapping, p_Request);
        } catch (Throwable t) {
            addGlobalError(t);
            saveErrors(p_Request, m_Errors);
            return (p_Mapping.findForward("Global Error"));
        }

        // Forward to the jsp.
        return (p_Mapping.findForward("Create Joram User"));
    }
}
